@@ -4,6 +4,7 @@
 #
 # Distributed under the BSD license, see LICENSE.txt
 from .cssselectpatch import JQueryTranslator
+from .openers import url_opener
 from copy import deepcopy
 from lxml import etree
 import lxml.html
@@ -13,13 +14,11 @@ import sys
 PY3k = sys.version_info >= (3,)
 
 if PY3k:
-    from urllib.request import urlopen
     from urllib.parse import urlencode
     from urllib.parse import urljoin
     basestring = (str, bytes)
     unicode = str
 else:
-    from urllib2 import urlopen  # NOQA
     from urllib import urlencode  # NOQA
     from urlparse import urljoin  # NOQA
 
@@ -66,8 +65,10 @@ def fromstring(context, parser=None, custom_parser=None):
         return result
     elif isinstance(result, etree._ElementTree):
         return [result.getroot()]
-    else:
+    elif result is not None:
         return [result]
+    else:
+        return []
 
 
 def callback(func, *args):
@@ -129,8 +130,8 @@ class PyQuery(list):
 
         if len(args) >= 1 and \
            (not PY3k and isinstance(args[0], basestring) or \
-            PY3k and isinstance(args[0], str)) and \
-           args[0].startswith('http://'):
+           (PY3k and isinstance(args[0], str))) and \
+           args[0].split('://', 1)[0] in ('http', 'https'):
             kwargs['url'] = args[0]
             if len(args) >= 2:
                 kwargs['data'] = args[1]
@@ -157,39 +158,28 @@ class PyQuery(list):
         if kwargs:
             # specific case to get the dom
             if 'filename' in kwargs:
-                fd = open(kwargs['filename'])
-                html = fd.read()
-                fd.close()
+                html = open(kwargs['filename'])
             elif 'url' in kwargs:
                 url = kwargs.pop('url')
                 if 'opener' in kwargs:
                     opener = kwargs.pop('opener')
-                    html = opener(url)
+                    html = opener(url, **kwargs)
                 else:
-                    method = kwargs.get('method')
-                    data = kwargs.get('data')
-                    if type(data) in (dict, list, tuple):
-                        data = urlencode(data)
-
-                    if isinstance(method, basestring) and \
-                       method.lower() == 'get' and data:
-                        if '?' not in url:
-                            url += '?'
-                        elif url[-1] not in ('?', '&'):
-                            url += '&'
-                        url += data
-                        data = None
-
-                    if data and PY3k:
-                        data = data.encode('utf-8')
-
-                    html = urlopen(url, data)
-                    if not self.parser:
-                        self.parser = 'html'
+                    html = url_opener(url, kwargs)
+                if not self.parser:
+                    self.parser = 'html'
                 self._base_url = url
             else:
                 raise ValueError('Invalid keyword arguments %s' % kwargs)
+
             elements = fromstring(html, self.parser)
+            # close open descriptor if possible
+            if hasattr(html, 'close'):
+                try:
+                    html.close()
+                except:
+                    pass
+
         else:
             # get nodes
 
@@ -221,12 +211,10 @@ class PyQuery(list):
             # select nodes
             if elements and selector is not no_default:
                 xpath = self._css_to_xpath(selector)
-                results = [tag.xpath(xpath, namespaces=namespaces) \
-                                                    for tag in elements]
-                # Flatten the results
-                elements = []
-                for r in results:
-                    elements.extend(r)
+                results = []
+                for tag in elements:
+                    results.extend(tag.xpath(xpath, namespaces=namespaces))
+                elements = results
 
         list.__init__(self, elements)
 
@@ -276,6 +264,43 @@ class PyQuery(list):
         for elem in elems:
             yield self.__class__(elem)
 
+    def xhtml_to_html(self):
+        """Remove xhtml namespace:
+
+            >>> doc = PyQuery(
+            ...         '<html xmlns="http://www.w3.org/1999/xhtml"></html>')
+            >>> doc
+            [<{http://www.w3.org/1999/xhtml}html>]
+            >>> doc.remove_namespaces()
+            [<html>]
+        """
+        try:
+            root = self[0].getroottree()
+        except IndexError:
+            pass
+        else:
+            lxml.html.xhtml_to_html(root)
+        return self
+
+    def remove_namespaces(self):
+        """Remove all namespaces:
+
+            >>> doc = PyQuery('<foo xmlns="http://example.com/foo"></foo>')
+            >>> doc
+            [<{http://example.com/foo}foo>]
+            >>> doc.remove_namespaces()
+            [<foo>]
+        """
+        try:
+            root = self[0].getroottree()
+        except IndexError:
+            pass
+        else:
+            for el in root.iter('{*}*'):
+                if el.tag.startswith('{'):
+                    el.tag = el.tag.split('}', 1)[1]
+        return self
+
     def __str__(self):
         """xml representation of current nodes::
 
@@ -879,7 +904,7 @@ class PyQuery(list):
             >>> print(d.html())
             <span>toto</span>
 
-        Extra args are passed to ``lxml.etree.tostring::
+        Extra args are passed to ``lxml.etree.tostring``::
 
             >>> d = PyQuery('<div><span></span></div>')
             >>> print(d.html())
